package OpenTelemetry::Any;

use strict;
use warnings;

our $VERSION = '0.001'; # VERSION
our $AUTHORITY = 'cpan:TEAM'; # AUTHORITY

no indirect;
use utf8;

=encoding utf8

=head1 NAME

OpenTelemetry::Any - general API for including OpenTelemetry in code

=head1 DESCRIPTION

Please see L<OpenTelemetry> for more background.

=cut

1;

__END__

=head1 AUTHOR

Tom Molesworth C<< TEAM@cpan.org >>

=head1 LICENSE

Copyright Tom Molesworth 2020. Licensed under the same terms as Perl itself.

